@@ -4,6 +4,7 @@ cal_apply_multi <- function(object, .data, pred_class) {
   UseMethod("cal_apply_multi")
 }
 
+#' @export
 cal_apply_multi.cal_estimate_multinomial <-
   function(object, .data, pred_class = NULL, ...) {
     apply_multi_predict(
@@ -22,15 +23,15 @@ apply_multi_predict <- function(object, .data) {
   } else {
     prob_type <- "probs"
   }
-  preds <- object$estimates[[1]]$estimate %>%
+  preds <- object$estimates[[1]]$estimate |>
     predict(newdata = .data, type = prob_type)
 
-  colnames(preds) <- as.character(object$levels)
+  lvls <- nm_levels(object$levels)
+  colnames(preds) <- lvls
   preds <- dplyr::as_tibble(preds)
 
-  for (i in seq_along(object$levels)) {
-    lev <- object$levels[i]
-    .data[, as.character(lev)] <- preds[, as.character(lev)]
+  for (i in seq_along(lvls)) {
+    .data[, lvls[i]] <- preds[, lvls[i]]
   }
   .data
 }
